@@ -45,6 +45,7 @@ from calculate.lib.utils.portage import (Layman, EmergeLog,
                                          get_packages_files_directory,
                                          get_manifest_files_directory,
                                          get_remove_list)
+from calculate.lib.utils.text import _u8
 
 Colors = TextState.Colors
 from calculate.lib.utils.files import (getProgPath, STDOUT, removeDir,
@@ -701,10 +702,10 @@ class Update(MethodsInterface):
                 size = ""
             mult = _print.bold("*")
             self.printDefault(
-                "&nbsp;{mult} {fullname}{flag}{shortname}{size}".format(
-                    mult=mult, fullname=fullname, shortname=shortname,
-                    size=size,
-                    flag=install_flag))
+                _u8("&nbsp;{mult} {fullname}{flag}{shortname}{size}").format(
+                    mult=_u8(mult), fullname=_u8(fullname), shortname=_u8(shortname),
+                    size=_u8(size),
+                    flag=_u8(install_flag)))
 
     def _display_install_package(self, emerge, emergelike=False):
         """
